package com.ruoyi.business.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.HwElectronicFenceMapper;
import com.ruoyi.business.domain.HwElectronicFence;
import com.ruoyi.business.service.IHwElectronicFenceService;

/**
 * 电子围栏Service业务层处理
 * 
 * @author xins
 * @date 2023-09-04
 */
@Service
public class HwElectronicFenceServiceImpl implements IHwElectronicFenceService 
{
    @Autowired
    private HwElectronicFenceMapper hwElectronicFenceMapper;

    /**
     * 查询电子围栏
     * 
     * @param electronicFenceId 电子围栏主键
     * @return 电子围栏
     */
    @Override
    public HwElectronicFence selectHwElectronicFenceByElectronicFenceId(Long electronicFenceId)
    {
        return hwElectronicFenceMapper.selectHwElectronicFenceByElectronicFenceId(electronicFenceId);
    }

    /**
     * 查询电子围栏列表
     * 
     * @param hwElectronicFence 电子围栏
     * @return 电子围栏
     */
    @Override
    public List<HwElectronicFence> selectHwElectronicFenceList(HwElectronicFence hwElectronicFence)
    {
        return hwElectronicFenceMapper.selectHwElectronicFenceList(hwElectronicFence);
    }

    /**
     * 新增电子围栏
     * 
     * @param hwElectronicFence 电子围栏
     * @return 结果
     */
    @Override
    public int insertHwElectronicFence(HwElectronicFence hwElectronicFence)
    {
        hwElectronicFence.setCreateTime(DateUtils.getNowDate());
        return hwElectronicFenceMapper.insertHwElectronicFence(hwElectronicFence);
    }

    /**
     * 修改电子围栏
     * 
     * @param hwElectronicFence 电子围栏
     * @return 结果
     */
    @Override
    public int updateHwElectronicFence(HwElectronicFence hwElectronicFence)
    {
        hwElectronicFence.setUpdateTime(DateUtils.getNowDate());
        return hwElectronicFenceMapper.updateHwElectronicFence(hwElectronicFence);
    }

    /**
     * 批量删除电子围栏
     * 
     * @param electronicFenceIds 需要删除的电子围栏主键
     * @return 结果
     */
    @Override
    public int deleteHwElectronicFenceByElectronicFenceIds(Long[] electronicFenceIds)
    {
        return hwElectronicFenceMapper.deleteHwElectronicFenceByElectronicFenceIds(electronicFenceIds);
    }

    /**
     * 删除电子围栏信息
     * 
     * @param electronicFenceId 电子围栏主键
     * @return 结果
     */
    @Override
    public int deleteHwElectronicFenceByElectronicFenceId(Long electronicFenceId)
    {
        return hwElectronicFenceMapper.deleteHwElectronicFenceByElectronicFenceId(electronicFenceId);
    }
}
